@@ -84,6 +84,10 @@ class ExportDB_ABC(ABC):
     def get_sidecar_for_file(self, filename):
         pass
 
+    @abstractmethod
+    def get_previous_uuids(self):
+        pass
+
     @abstractmethod
     def set_data(
         self,
@@ -155,6 +159,9 @@ class ExportDBNoOp(ExportDB_ABC):
     def get_sidecar_for_file(self, filename):
         return None, (None, None, None)
 
+    def get_previous_uuids(self):
+        return []
+
     def set_data(
         self,
         filename,
@@ -435,6 +442,19 @@ class ExportDB(ExportDB_ABC):
         except Error as e:
             logging.warning(e)
 
+    def get_previous_uuids(self):
+        """returns list of UUIDs of previously exported photos found in export database """
+        conn = self._conn
+        previous_uuids = []
+        try:
+            c = conn.cursor()
+            c.execute("SELECT DISTINCT uuid FROM files")
+            results = c.fetchall()
+            previous_uuids = [row[0] for row in results]
+        except Error as e:
+            logging.warning(e)
+        return previous_uuids
+
     def set_data(
         self,
         filename,
