@@ -87,6 +87,8 @@ class ExportResults:
         exiftool_error=None,
         xattr_written=None,
         xattr_skipped=None,
+        deleted_files=None,
+        deleted_directories=None,
     ):
         self.exported = exported or []
         self.new = new or []
@@ -107,6 +109,8 @@ class ExportResults:
         self.exiftool_error = exiftool_error or []
         self.xattr_written = xattr_written or []
         self.xattr_skipped = xattr_skipped or []
+        self.deleted_files = deleted_files or []
+        self.deleted_directories = deleted_directories or []
 
     def all_files(self):
         """ return all filenames contained in results """
@@ -151,6 +155,8 @@ class ExportResults:
         self.error += other.error
         self.exiftool_warning += other.exiftool_warning
         self.exiftool_error += other.exiftool_error
+        self.deleted_files += other.deleted_files
+        self.deleted_directories += other.deleted_directories
         return self
 
     def __str__(self):
@@ -173,6 +179,8 @@ class ExportResults:
             + f",error={self.error}"
             + f",exiftool_warning={self.exiftool_warning}"
             + f",exiftool_error={self.exiftool_error}"
+            + f",deleted_files={self.deleted_files}"
+            + f",deleted_directories={self.deleted_directories}"
             + ")"
         )
 
@@ -475,6 +483,9 @@ def export2(
     merge_exif_keywords=False,
     merge_exif_persons=False,
     jpeg_ext=None,
+    persons=True,
+    location=True,
+    replace_keywords=False,
 ):
     """export photo, like export but with update and dry_run options
     dest: must be valid destination path or exception raised
@@ -527,6 +538,9 @@ def export2(
     merge_exif_keywords: boolean; if True, merged keywords found in file's exif data (requires exiftool)
     merge_exif_persons: boolean; if True, merged persons found in file's exif data (requires exiftool)
     jpeg_ext: if set, will use this value for extension on jpegs converted to jpeg with convert_to_jpeg; if not set, uses jpeg; do not include the leading "."
+    persons: if True, include persons in exported metadata
+    location: if True, include location in exported metadata
+    replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
 
     Returns: ExportResults class 
         ExportResults has attributes: 
@@ -607,9 +621,9 @@ def export2(
                 )
             edited_name = pathlib.Path(self.path_edited).name
             edited_suffix = pathlib.Path(edited_name).suffix
-            fname = pathlib.Path(self.filename).stem + edited_identifier + edited_suffix
+            fname = pathlib.Path(self.original_filename).stem + edited_identifier + edited_suffix
         else:
-            fname = self.filename
+            fname = self.original_filename
 
     uti = self.uti if edited else self.uti_original
     if convert_to_jpeg and self.isphoto and uti != "public.jpeg":
@@ -941,6 +955,9 @@ def export2(
             merge_exif_keywords=merge_exif_keywords,
             merge_exif_persons=merge_exif_persons,
             filename=dest.name,
+            persons=persons,
+            location=location,
+            replace_keywords=replace_keywords,
         )
         sidecars.append(
             (
@@ -964,6 +981,9 @@ def export2(
             merge_exif_keywords=merge_exif_keywords,
             merge_exif_persons=merge_exif_persons,
             filename=dest.name,
+            persons=persons,
+            location=location,
+            replace_keywords=replace_keywords,
         )
         sidecars.append(
             (
@@ -983,6 +1003,9 @@ def export2(
             keyword_template=keyword_template,
             description_template=description_template,
             extension=dest.suffix[1:] if dest.suffix else None,
+            persons=persons,
+            location=location,
+            replace_keywords=replace_keywords,
         )
         sidecars.append(
             (
@@ -1050,6 +1073,9 @@ def export2(
                         ignore_date_modified=ignore_date_modified,
                         merge_exif_keywords=merge_exif_keywords,
                         merge_exif_persons=merge_exif_persons,
+                        persons=persons,
+                        location=location,
+                        replace_keywords=replace_keywords,
                     )
                 )[0]
                 if old_data != current_data:
@@ -1070,6 +1096,9 @@ def export2(
                         flags=exiftool_flags,
                         merge_exif_keywords=merge_exif_keywords,
                         merge_exif_persons=merge_exif_persons,
+                        persons=persons,
+                        location=location,
+                        replace_keywords=replace_keywords,
                     )
                     if warning_:
                         all_results.exiftool_warning.append((exported_file, warning_))
@@ -1087,6 +1116,9 @@ def export2(
                         ignore_date_modified=ignore_date_modified,
                         merge_exif_keywords=merge_exif_keywords,
                         merge_exif_persons=merge_exif_persons,
+                        persons=persons,
+                        location=location,
+                        replace_keywords=replace_keywords,
                     ),
                 )
                 export_db.set_stat_exif_for_file(
@@ -1109,6 +1141,9 @@ def export2(
                     flags=exiftool_flags,
                     merge_exif_keywords=merge_exif_keywords,
                     merge_exif_persons=merge_exif_persons,
+                    persons=persons,
+                    location=location,
+                    replace_keywords=replace_keywords,
                 )
                 if warning_:
                     all_results.exiftool_warning.append((exported_file, warning_))
@@ -1126,6 +1161,9 @@ def export2(
                     ignore_date_modified=ignore_date_modified,
                     merge_exif_keywords=merge_exif_keywords,
                     merge_exif_persons=merge_exif_persons,
+                    persons=persons,
+                    location=location,
+                    replace_keywords=replace_keywords,
                 ),
             )
             export_db.set_stat_exif_for_file(
@@ -1345,6 +1383,9 @@ def _write_exif_data(
     flags=None,
     merge_exif_keywords=False,
     merge_exif_persons=False,
+    persons=True,
+    location=True,
+    replace_keywords=False,
 ):
     """write exif data to image file at filepath
 
@@ -1355,6 +1396,9 @@ def _write_exif_data(
         keyword_template: (list of strings); list of template strings to render as keywords
         ignore_date_modified: if True, sets EXIF:ModifyDate to EXIF:DateTimeOriginal even if date_modified is set
         flags: optional list of exiftool flags to prepend to exiftool command when writing metadata (e.g. -m or -F)
+        persons: if True, write person data to metadata
+        location: if True, write location data to metadata
+        replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
 
     Returns:
         (warning, error) of warning and error strings if exiftool produces warnings or errors
@@ -1369,6 +1413,9 @@ def _write_exif_data(
         ignore_date_modified=ignore_date_modified,
         merge_exif_keywords=merge_exif_keywords,
         merge_exif_persons=merge_exif_persons,
+        persons=persons,
+        location=location,
+        replace_keywords=replace_keywords,
     )
 
     with ExifTool(filepath, flags=flags, exiftool=self._db._exiftool_path) as exiftool:
@@ -1391,6 +1438,9 @@ def _exiftool_dict(
     merge_exif_keywords=False,
     merge_exif_persons=False,
     filename=None,
+    persons=True,
+    location=True,
+    replace_keywords=False,
 ):
     """Return dict of EXIF details for building exiftool JSON sidecar or sending commands to ExifTool.
         Does not include all the EXIF fields as those are likely already in the image.
@@ -1404,6 +1454,9 @@ def _exiftool_dict(
         ignore_date_modified: if True, sets EXIF:ModifyDate to EXIF:DateTimeOriginal even if date_modified is set
         merge_exif_keywords: merge keywords in the file's exif metadata (requires exiftool)
         merge_exif_persons: merge persons in the file's exif metadata (requires exiftool)
+        persons: if True, include person data
+        location: if True, include location data
+        replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
 
     Returns: dict with exiftool tags / values
 
@@ -1411,8 +1464,10 @@ def _exiftool_dict(
         EXIF:ImageDescription (may include template)
         XMP:Description (may include template)
         XMP:Title
+        IPTC:ObjectName
         XMP:TagsList (may include album name, person name, or template)
         IPTC:Keywords (may include album name, person name, or template)
+        IPTC:Caption-Abstract
         XMP:Subject (set to keywords + persons)
         XMP:PersonInImage
         EXIF:GPSLatitudeRef, EXIF:GPSLongitudeRef
@@ -1428,6 +1483,9 @@ def _exiftool_dict(
         QuickTime:ModifyDate (UTC)
         QuickTime:GPSCoordinates
         UserData:GPSCoordinates
+
+    Reference: 
+        https://iptc.org/std/photometadata/specification/IPTC-PhotoMetadata-201610_1.pdf
     """
 
     exif = (
@@ -1447,30 +1505,34 @@ def _exiftool_dict(
         description = " ".join(rendered) if rendered else ""
         exif["EXIF:ImageDescription"] = description
         exif["XMP:Description"] = description
+        exif["IPTC:Caption-Abstract"] = description
     elif self.description:
         exif["EXIF:ImageDescription"] = self.description
         exif["XMP:Description"] = self.description
+        exif["IPTC:Caption-Abstract"] = self.description
 
     if self.title:
         exif["XMP:Title"] = self.title
+        exif["IPTC:ObjectName"] = self.title
 
     keyword_list = []
     if merge_exif_keywords:
         keyword_list.extend(self._get_exif_keywords())
 
-    if self.keywords:
+    if self.keywords and not replace_keywords:
         keyword_list.extend(self.keywords)
 
     person_list = []
-    if merge_exif_persons:
-        person_list.extend(self._get_exif_persons())
+    if persons:
+        if merge_exif_persons:
+            person_list.extend(self._get_exif_persons())
 
-    if self.persons:
-        # filter out _UNKNOWN_PERSON
-        person_list.extend([p for p in self.persons if p != _UNKNOWN_PERSON])
+        if self.persons:
+            # filter out _UNKNOWN_PERSON
+            person_list.extend([p for p in self.persons if p != _UNKNOWN_PERSON])
 
-    if use_persons_as_keywords and person_list:
-        keyword_list.extend(person_list)
+        if use_persons_as_keywords and person_list:
+            keyword_list.extend(person_list)
 
     if use_albums_as_keywords and self.albums:
         keyword_list.extend(self.albums)
@@ -1514,25 +1576,26 @@ def _exiftool_dict(
         exif["XMP:Subject"] = keyword_list.copy()
         exif["XMP:TagsList"] = keyword_list.copy()
 
-    if person_list:
+    if persons and person_list:
         person_list = sorted(list(set(person_list)))
         exif["XMP:PersonInImage"] = person_list.copy()
 
     # if self.favorite():
     #     exif["Rating"] = 5
 
-    (lat, lon) = self.location
-    if lat is not None and lon is not None:
-        if self.isphoto:
-            exif["EXIF:GPSLatitude"] = lat
-            exif["EXIF:GPSLongitude"] = lon
-            lat_ref = "N" if lat >= 0 else "S"
-            lon_ref = "E" if lon >= 0 else "W"
-            exif["EXIF:GPSLatitudeRef"] = lat_ref
-            exif["EXIF:GPSLongitudeRef"] = lon_ref
-        elif self.ismovie:
-            exif["Keys:GPSCoordinates"] = f"{lat} {lon}"
-            exif["UserData:GPSCoordinates"] = f"{lat} {lon}"
+    if location:
+        (lat, lon) = self.location
+        if lat is not None and lon is not None:
+            if self.isphoto:
+                exif["EXIF:GPSLatitude"] = lat
+                exif["EXIF:GPSLongitude"] = lon
+                lat_ref = "N" if lat >= 0 else "S"
+                lon_ref = "E" if lon >= 0 else "W"
+                exif["EXIF:GPSLatitudeRef"] = lat_ref
+                exif["EXIF:GPSLongitudeRef"] = lon_ref
+            elif self.ismovie:
+                exif["Keys:GPSCoordinates"] = f"{lat} {lon}"
+                exif["UserData:GPSCoordinates"] = f"{lat} {lon}"
 
     # process date/time and timezone offset
     # Photos exports the following fields and sets modify date to creation date
@@ -1591,6 +1654,13 @@ def _exiftool_dict(
             exif["QuickTime:ModifyDate"] = datetime_tz_to_utc(
                 self.date_modified
             ).strftime("%Y:%m:%d %H:%M:%S")
+    
+    # remove any new lines in any fields
+    for field, val in exif.items():
+        if type(val) == str:
+            exif[field] = val.replace("\n", " ")
+        elif type(val) == list:
+            exif[field] = [str(v).replace("\n", " ") for v in val if v is not None]
     return exif
 
 
@@ -1640,6 +1710,9 @@ def _exiftool_json_sidecar(
     merge_exif_keywords=False,
     merge_exif_persons=False,
     filename=None,
+    persons=True,
+    location=True,
+    replace_keywords=False,
 ):
     """Return dict of EXIF details for building exiftool JSON sidecar or sending commands to ExifTool.
         Does not include all the EXIF fields as those are likely already in the image.
@@ -1654,13 +1727,18 @@ def _exiftool_json_sidecar(
         merge_exif_keywords: boolean; if True, merged keywords found in file's exif data (requires exiftool)
         merge_exif_persons: boolean; if True, merged persons found in file's exif data (requires exiftool)
         filename: filename of the destination image file for including in exiftool signature in JSON sidecar
+        persons: if True, include person data
+        location: if True, include location data
+        replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
 
     Returns: dict with exiftool tags / values
 
     Exports the following:
         EXIF:ImageDescription
         XMP:Description (may include template)
+        IPTC:CaptionAbstract
         XMP:Title
+        IPTC:ObjectName
         XMP:TagsList
         IPTC:Keywords (may include album name, person name, or template)
         XMP:Subject (set to keywords + person)
@@ -1688,6 +1766,9 @@ def _exiftool_json_sidecar(
         merge_exif_keywords=merge_exif_keywords,
         merge_exif_persons=merge_exif_persons,
         filename=filename,
+        persons=persons,
+        location=location,
+        replace_keywords=replace_keywords,
     )
 
     if not tag_groups:
@@ -1710,6 +1791,9 @@ def _xmp_sidecar(
     extension=None,
     merge_exif_keywords=False,
     merge_exif_persons=False,
+    persons=True,
+    location=True,
+    replace_keywords=False,
 ):
     """returns string for XMP sidecar
     use_albums_as_keywords: treat album names as keywords
@@ -1719,6 +1803,9 @@ def _xmp_sidecar(
     extension: which extension to use for SidecarForExtension property
     merge_exif_keywords: boolean; if True, merged keywords found in file's exif data (requires exiftool)
     merge_exif_persons: boolean; if True, merged persons found in file's exif data (requires exiftool)
+    persons: if True, include person data
+    location: if True, include location data
+    replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
     """
 
     xmp_template_file = (
@@ -1742,22 +1829,23 @@ def _xmp_sidecar(
     if merge_exif_keywords:
         keyword_list.extend(self._get_exif_keywords())
 
-    if self.keywords:
+    if self.keywords and not replace_keywords:
         keyword_list.extend(self.keywords)
 
     # TODO: keyword handling in this and _exiftool_json_sidecar is
     # good candidate for pulling out in a function
 
     person_list = []
-    if merge_exif_persons:
-        person_list.extend(self._get_exif_persons())
+    if persons:
+        if merge_exif_persons:
+            person_list.extend(self._get_exif_persons())
 
-    if self.persons:
-        # filter out _UNKNOWN_PERSON
-        person_list.extend([p for p in self.persons if p != _UNKNOWN_PERSON])
+        if self.persons:
+            # filter out _UNKNOWN_PERSON
+            person_list.extend([p for p in self.persons if p != _UNKNOWN_PERSON])
 
-    if use_persons_as_keywords and person_list:
-        keyword_list.extend(person_list)
+        if use_persons_as_keywords and person_list:
+            keyword_list.extend(person_list)
 
     if use_albums_as_keywords and self.albums:
         keyword_list.extend(self.albums)
@@ -1787,11 +1875,14 @@ def _xmp_sidecar(
     # sorted mainly to make testing the XMP file easier
     if keyword_list:
         keyword_list = sorted(list(set(keyword_list)))
-    if person_list:
+    if persons and person_list:
         person_list = sorted(list(set(person_list)))
 
     subject_list = keyword_list
 
+    if location:
+        latlon = self.location
+
     xmp_str = xmp_template.render(
         photo=self,
         description=description,
@@ -1799,6 +1890,7 @@ def _xmp_sidecar(
         persons=person_list,
         subjects=subject_list,
         extension=extension,
+        location=latlon,
         version=__version__,
     )
 
