@@ -27,6 +27,7 @@ from .._constants import (
     _PHOTOS_5_SHARED_PHOTO_PATH,
     _PHOTOS_5_VERSION,
 )
+from ..adjustmentsinfo import AdjustmentsInfo
 from ..albuminfo import AlbumInfo, ImportInfo
 from ..personinfo import FaceInfo, PersonInfo
 from ..phototemplate import PhotoTemplate
@@ -452,9 +453,24 @@ class PhotoInfo:
             )
             return self._albums
 
+    @property
+    def burst_albums(self):
+        """If photo is non-selected burst photo, list of albums any other images in the same burst set are contained in, otherwise returns self.albums"""
+        if self.burst_selected or not self.burst:
+            return self.albums
+
+        try:
+            return self._burst_albums
+        except AttributeError:
+            burst_albums = []
+            for photo in self.burst_photos:
+                burst_albums.extend(photo.albums)
+            self._burst_albums = list(set(burst_albums))
+            return self._burst_albums
+
     @property
     def album_info(self):
-        """ list of AlbumInfo objects representing albums the photos is contained in """
+        """ list of AlbumInfo objects representing albums the photo is contained in """
         try:
             return self._album_info
         except AttributeError:
@@ -464,6 +480,21 @@ class PhotoInfo:
             ]
             return self._album_info
 
+    @property
+    def burst_album_info(self):
+        """ If photo is a non-selected burst photo, returns list of AlbumInfo objects representing albums any other photos in the same burst set are contained in, otherwise returns self.album_info """
+        if self.burst_selected or not self.burst:
+            return self.album_info
+
+        try:
+            return self._burst_album_info
+        except AttributeError:
+            burst_album_info = []
+            for photo in self.burst_photos:
+                burst_album_info.extend(photo.album_info)
+            self._burst_album_info = list(set(burst_album_info))
+            return self._burst_album_info
+
     @property
     def import_info(self):
         """ ImportInfo object representing import session for the photo or None if no import session """
@@ -510,6 +541,30 @@ class PhotoInfo:
         """ True if picture has adjustments / edits """
         return self._info["hasAdjustments"] == 1
 
+    @property
+    def adjustments(self):
+        """ Returns AdjustmentsInfo class for adjustment data or None if no adjustments; Photos 5+ only """
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return None
+
+        if self.hasadjustments:
+            try:
+                return self._adjustmentinfo
+            except AttributeError:
+                library = self._db._library_path
+                directory = self._uuid[0]  # first char of uuid
+                plist_file = (
+                    pathlib.Path(library)
+                    / "resources"
+                    / "renders"
+                    / directory
+                    / f"{self._uuid}.plist"
+                )
+                if not plist_file.is_file():
+                    return None
+                self._adjustmentinfo = AdjustmentsInfo(plist_file)
+                return self._adjustmentinfo
+
     @property
     def external_edit(self):
         """ Returns True if picture was edited outside of Photos using external editor """
@@ -655,6 +710,11 @@ class PhotoInfo:
         """ Returns True if photo is part of a Burst photo set, otherwise False """
         return self._info["burst"]
 
+    @property
+    def burst_selected(self):
+        """ Returns True if photo is a burst photo and has been selected from the burst set by the user, otherwise False """
+        return self._info["burst_key"]
+
     @property
     def burst_photos(self):
         """If photo is a burst photo, returns list of PhotoInfo objects
@@ -823,8 +883,19 @@ class PhotoInfo:
 
     @property
     def orientation(self):
-        """ returns EXIF orientation of the current photo version as int """
-        return self._info["orientation"]
+        """ returns EXIF orientation of the current photo version as int or 0 if current orientation cannot be determined """
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return self._info["orientation"]
+
+        # For Photos 5+, try to get the adjusted orientation
+        if self.hasadjustments:
+            if self.adjustments:
+                return self.adjustments.adj_orientation
+            else:
+                # can't reliably determine orientation for edited photo if adjustmentinfo not available
+                return 0
+        else:
+            return self._info["orientation"]
 
     @property
     def original_height(self):
